@@ -14,7 +14,6 @@ from supervised.algorithms.registry import (
     MULTICLASS_CLASSIFICATION,
     REGRESSION,
 )
-from supervised.utils.config import storage_path
 from supervised.utils.config import LOG_LEVEL
 
 logger = logging.getLogger(__name__)
@@ -29,8 +28,6 @@ class LightgbmAlgorithm(BaseAlgorithm):
     def __init__(self, params):
         super(LightgbmAlgorithm, self).__init__(params)
         self.library_version = lgb.__version__
-        self.model_file = self.uid + ".lgbm.model"
-        self.model_file_path = os.path.join(storage_path, self.model_file)
 
         self.rounds = additional.get("trees_in_step", 50)
         self.max_iters = additional.get("max_steps", 500)
@@ -52,7 +49,7 @@ class LightgbmAlgorithm(BaseAlgorithm):
 
         logger.debug("LightgbmLearner __init__")
 
-    def file_extenstion(self):
+    def file_extension(self):
         return "lightgbm"
 
     def update(self, update_params):
@@ -82,9 +79,6 @@ class LightgbmAlgorithm(BaseAlgorithm):
         logger.debug("LightgbmAlgorithm load model from %s" % model_file_path)
         self.model = lgb.Booster(model_file=model_file_path)
 
-    def importance(self, column_names, normalize=True):
-        return None
-
     def get_params(self):
         json_desc = {
             "library_version": self.library_version,
@@ -129,7 +123,6 @@ required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
     "target_as_integer",
-    "target_scale",
 ]
 
 
@@ -158,6 +151,17 @@ AlgorithmsRegistry.add(
     additional,
 )
 
+regression_required_preprocessing = [
+    "missing_values_inputation",
+    "convert_categorical",
+    "target_scale",
+]
+
+
 AlgorithmsRegistry.add(
-    REGRESSION, LightgbmAlgorithm, lgbr_params, required_preprocessing, additional
+    REGRESSION,
+    LightgbmAlgorithm,
+    lgbr_params,
+    regression_required_preprocessing,
+    additional,
 )
