@@ -54,6 +54,9 @@ class XgbAlgorithm(BaseAlgorithm):
             "seed": self.params.get("seed", 1),
         }
 
+        # check https://github.com/dmlc/xgboost/issues/5637
+        if self.learner_params["seed"] > 1000:
+            self.learner_params["seed"] = self.learner_params["seed"] % 1000
         if "num_class" in self.params:  # multiclass classification
             self.learner_params["num_class"] = self.params.get("num_class")
 
