@@ -12,9 +12,8 @@ from supervised.validation.validation_step import ValidationStep
 from supervised.algorithms.factory import AlgorithmFactory
 from supervised.preprocessing.preprocessing import Preprocessing
 from supervised.preprocessing.exclude_missing_target import ExcludeRowsMissingTarget
-
+from supervised.algorithms.registry import AlgorithmsRegistry
 from supervised.exceptions import AutoMLException
-from supervised.utils.config import storage_path
 from supervised.utils.config import LOG_LEVEL
 from supervised.utils.additional_metrics import AdditionalMetrics
 
@@ -52,6 +51,7 @@ class ModelFramework:
         self.learner_params = params.get("learner")
 
         self._ml_task = params.get("ml_task")
+        self._explain_level = params.get("explain_level")
 
         self.validation = None
         self.preprocessings = []
@@ -154,9 +154,14 @@ class ModelFramework:
             learner.interpret(
                 X_train,
                 y_train,
+                X_validation,
+                y_validation,
                 model_file_path=model_path,
                 learner_name=f"learner_{k_fold+1}",
                 class_names=self.preprocessings[-1].get_target_class_names(),
+                metric_name=self.get_metric_name(),
+                ml_task=self._ml_task,
+                explain_level=self._explain_level,
             )
 
         # end of validation loop
@@ -250,7 +255,7 @@ class ModelFramework:
 
         saved = []
         for i, l in enumerate(self.learners):
-            p = os.path.join(model_path, f"learner_{i+1}.{l.file_extenstion()}")
+            p = os.path.join(model_path, f"learner_{i+1}.{l.file_extension()}")
             l.save(p)
             saved += [p]
 
@@ -295,8 +300,15 @@ class ModelFramework:
             fout.write("ALL OK!")
 
     def model_markdown(self):
+        long_name = AlgorithmsRegistry.get_long_name(
+            self._ml_task, self.learner_params["model_type"]
+        )
+        short_name = self.learner_params["model_type"]
         desc = f"# Summary of {self.get_name()}\n"
-        desc += f"\n ## {self.learner_params['model_type']}\n"
+        if long_name == short_name:
+            desc += f"\n## {short_name}\n"
+        else:
+            desc += f"\n## {long_name} ({short_name})\n"
         for k, v in self.learner_params.items():
             if k in ["model_type", "ml_task", "seed"]:
                 continue
