@@ -185,17 +185,22 @@ class AdditionalMetrics:
 
     @staticmethod
     def save(additional_metrics, ml_task, model_desc, model_path):
-        if ml_task == BINARY_CLASSIFICATION:
-            AdditionalMetrics.save_binary_classification(
-                additional_metrics, model_desc, model_path
-            )
-        elif ml_task == MULTICLASS_CLASSIFICATION:
-            AdditionalMetrics.save_multiclass_classification(
-                additional_metrics, model_desc, model_path
-            )
-        elif ml_task == REGRESSION:
-            AdditionalMetrics.save_regression(
-                additional_metrics, model_desc, model_path
+        try:
+            if ml_task == BINARY_CLASSIFICATION:
+                AdditionalMetrics.save_binary_classification(
+                    additional_metrics, model_desc, model_path
+                )
+            elif ml_task == MULTICLASS_CLASSIFICATION:
+                AdditionalMetrics.save_multiclass_classification(
+                    additional_metrics, model_desc, model_path
+                )
+            elif ml_task == REGRESSION:
+                AdditionalMetrics.save_regression(
+                    additional_metrics, model_desc, model_path
+                )
+        except Exception as e:
+            logger.info(
+                f"Exception while saving additional metrics. {str(e)}\nContinuing ..."
             )
 
     @staticmethod
@@ -351,151 +356,168 @@ class AdditionalMetrics:
 
     @staticmethod
     def add_shap_importance(fout, model_path):
+        try:
+            # SHAP Importance
+            imp_data = [f for f in os.listdir(model_path) if "_shap_importance.csv" in f]
+            if not len(imp_data):
+                return
+            df_all = []
+            for l in range(len(imp_data)):
+                f_path = os.path.join(model_path, f"learner_{l+1}_shap_importance.csv")
+                df = pd.read_csv(f_path, index_col=0)
+                df.columns = [f"Learner {l+1}"]
+                df_all += [df]
 
-        # SHAP Importance
-        imp_data = [f for f in os.listdir(model_path) if "_shap_importance.csv" in f]
-        if not len(imp_data):
-            return
-        df_all = []
-        for l in range(len(imp_data)):
-            f_path = os.path.join(model_path, f"learner_{l+1}_shap_importance.csv")
-            df = pd.read_csv(f_path, index_col=0)
-            df.columns = [f"Learner {l+1}"]
-            df_all += [df]
+            df = pd.concat(df_all, axis=1)
 
-        df = pd.concat(df_all, axis=1)
+            df["m"] = df.mean(axis=1)
+            df = df.sort_values(by="m", ascending=False)
+            df = df.drop("m", axis=1)
 
-        df["m"] = df.mean(axis=1)
-        df = df.sort_values(by="m", ascending=False)
-        df = df.drop("m", axis=1)
-
-        # limit to max 25 features in the plot
-        ax = df.head(25).plot.barh(figsize=(10, 7))
-        ax.invert_yaxis()
-        ax.set_xlabel("mean(|SHAP value|) average impact on model output magnitude")
-        fig = ax.get_figure()
-        fig.tight_layout(pad=2.0)
-        if df.shape[0] > 25:
-            ax.set_title("SHAP Top-25 important features")
-        else:
-            ax.set_title("SHAP feature importance")
-        fig.savefig(os.path.join(model_path, "shap_importance.png"))
-        fout.write("\n\n## SHAP Importance\n")
-        fout.write(f"![SHAP Importance](shap_importance.png)")
+            # limit to max 25 features in the plot
+            ax = df.head(25).plot.barh(figsize=(10, 7))
+            ax.invert_yaxis()
+            ax.set_xlabel("mean(|SHAP value|) average impact on model output magnitude")
+            fig = ax.get_figure()
+            fig.tight_layout(pad=2.0)
+            if df.shape[0] > 25:
+                ax.set_title("SHAP Top-25 important features")
+            else:
+                ax.set_title("SHAP feature importance")
+            fig.savefig(os.path.join(model_path, "shap_importance.png"))
+            fout.write("\n\n## SHAP Importance\n")
+            fout.write(f"![SHAP Importance](shap_importance.png)")
+        except Exception as e:
+            logger.info(
+                f"Exception while saving SHAP importance. {str(e)}\nContinuing ..."
+            )
 
     @staticmethod
     def add_shap_binary(fout, model_path):
+        try:
+            # Dependence SHAP
+            dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence.png" in f]
+            if not len(dep_plots):
+                return
 
-        # Dependence SHAP
-        dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence.png" in f]
-        if not len(dep_plots):
-            return
+            learners_cnt = len(dep_plots)
+            fout.write("\n\n## SHAP Dependence plots\n")
+            for l in range(learners_cnt):
+                fout.write(f"\n### Dependence (Fold #{l+1})\n")
+                f_path = f"learner_{l+1}_shap_dependence.png"
+                fout.write(f"![SHAP Dependence from fold {l+1}]({f_path})")
 
-        learners_cnt = len(dep_plots)
-        fout.write("\n\n## SHAP Dependence plots\n")
-        for l in range(learners_cnt):
-            fout.write(f"\n### Dependence (Fold #{l+1})\n")
-            f_path = f"learner_{l+1}_shap_dependence.png"
-            fout.write(f"![SHAP Dependence from fold {l+1}]({f_path})")
+            # SHAP Decisions
+            dec_plots = [
+                f
+                for f in os.listdir(model_path)
+                if "_shap_class" in f and "decisions.png" in f
+            ]
+            if not len(dec_plots):
+                return
 
-        # SHAP Decisions
-        dec_plots = [
-            f
-            for f in os.listdir(model_path)
-            if "_shap_class" in f and "decisions.png" in f
-        ]
-        if not len(dec_plots):
-            return
-
-        fout.write("\n\n## SHAP Decision plots\n")
-        for target in [0, 1]:
-            for decision_type in ["worst", "best"]:
-                for l in range(learners_cnt):
-                    fout.write(
-                        f"\n### Top-10 {decision_type.capitalize()} decisions for class {target} (Fold #{l+1})\n"
-                    )
-                    f_path = f"learner_{l+1}_shap_class_{target}_{decision_type}_decisions.png"
-                    fout.write(
-                        f"![SHAP {decision_type} decisions class {target} from fold {l+1}]({f_path})"
-                    )
+            fout.write("\n\n## SHAP Decision plots\n")
+            for target in [0, 1]:
+                for decision_type in ["worst", "best"]:
+                    for l in range(learners_cnt):
+                        fout.write(
+                            f"\n### Top-10 {decision_type.capitalize()} decisions for class {target} (Fold #{l+1})\n"
+                        )
+                        f_path = f"learner_{l+1}_shap_class_{target}_{decision_type}_decisions.png"
+                        fout.write(
+                            f"![SHAP {decision_type} decisions class {target} from fold {l+1}]({f_path})"
+                        )
+        except Exception as e:
+            logger.info(
+                f"Exception while saving SHAP explanations. {str(e)}\nContinuing ..."
+            )
 
     @staticmethod
     def add_shap_regression(fout, model_path):
+        try:
+            # Dependence SHAP
+            dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence.png" in f]
+            if not len(dep_plots):
+                return
 
-        # Dependence SHAP
-        dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence.png" in f]
-        if not len(dep_plots):
-            return
-
-        learners_cnt = len(dep_plots)
-        fout.write("\n\n## SHAP Dependence plots\n")
-        for l in range(learners_cnt):
-            fout.write(f"\n### Dependence (Fold #{l+1})\n")
-            f_path = f"learner_{l+1}_shap_dependence.png"
-            fout.write(f"![SHAP Dependence from fold {l+1}]({f_path})")
-
-        # SHAP Decisions
-        dec_plots = [f for f in os.listdir(model_path) if "decisions.png" in f]
-        if not len(dec_plots):
-            return
-
-        fout.write("\n\n## SHAP Decision plots\n")
-        for decision_type in ["worst", "best"]:
+            learners_cnt = len(dep_plots)
+            fout.write("\n\n## SHAP Dependence plots\n")
             for l in range(learners_cnt):
-                fout.write(
-                    f"\n### Top-10 {decision_type.capitalize()} decisions (Fold #{l+1})\n"
-                )
-                f_path = f"learner_{l+1}_shap_{decision_type}_decisions.png"
-                fout.write(
-                    f"![SHAP {decision_type} decisions from fold {l+1}]({f_path})"
-                )
-
-    @staticmethod
-    def add_shap_multiclass(fout, model_path):
-        # Dependence SHAP
-        dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence" in f]
-        if not len(dep_plots):
-            return
-
-        # get number of learners
-        learners_cnt = []
-        for l in dep_plots:
-            a = l.split("_")
-            learners_cnt += [int(a[1])]
-        learners_cnt = len(np.unique(learners_cnt))
-        # get number of classes
-        classes = []
-        for l in dep_plots:
-            a = l.split("_")
-            classes += ["".join(a[5:])[:-4]]
-        classes = np.unique(classes)
-
-        fout.write("\n\n## SHAP Dependence plots\n")
-        for l in range(learners_cnt):
-            for t in classes:
-                fout.write(f"\n### Dependence {t} (Fold #{l+1})\n")
-                f_path = f"learner_{l+1}_shap_dependence_class_{t}.png"
+                fout.write(f"\n### Dependence (Fold #{l+1})\n")
+                f_path = f"learner_{l+1}_shap_dependence.png"
                 fout.write(f"![SHAP Dependence from fold {l+1}]({f_path})")
 
-        # SHAP Decisions
-        dec_plots = [
-            f
-            for f in os.listdir(model_path)
-            if "_sample_" in f and "decisions.png" in f
-        ]
-        if not len(dec_plots):
-            return
+            # SHAP Decisions
+            dec_plots = [f for f in os.listdir(model_path) if "decisions.png" in f]
+            if not len(dec_plots):
+                return
 
-        fout.write("\n\n## SHAP Decision plots\n")
-        for decision_type in ["worst", "best"]:
-            for sample in [0, 1, 2, 3]:
+            fout.write("\n\n## SHAP Decision plots\n")
+            for decision_type in ["worst", "best"]:
                 for l in range(learners_cnt):
                     fout.write(
-                        f"\n### {decision_type.capitalize()} decisions for selected sample #{sample+1} (Fold #{l+1})\n"
-                    )
-                    f_path = (
-                        f"learner_{l+1}_sample_{sample}_{decision_type}_decisions.png"
+                        f"\n### Top-10 {decision_type.capitalize()} decisions (Fold #{l+1})\n"
                     )
+                    f_path = f"learner_{l+1}_shap_{decision_type}_decisions.png"
                     fout.write(
                         f"![SHAP {decision_type} decisions from fold {l+1}]({f_path})"
                     )
+        except Exception as e:
+            logger.info(
+                f"Exception while saving SHAP explanations. {str(e)}\nContinuing ..."
+            )
+
+    @staticmethod
+    def add_shap_multiclass(fout, model_path):
+        try:
+            # Dependence SHAP
+            dep_plots = [f for f in os.listdir(model_path) if "_shap_dependence" in f]
+            if not len(dep_plots):
+                return
+
+            # get number of learners
+            learners_cnt = []
+            for l in dep_plots:
+                a = l.split("_")
+                learners_cnt += [int(a[1])]
+            learners_cnt = len(np.unique(learners_cnt))
+            # get number of classes
+            classes = []
+            for l in dep_plots:
+                a = l.split("_")
+                classes += ["".join(a[5:])[:-4]]
+            classes = np.unique(classes)
+
+            fout.write("\n\n## SHAP Dependence plots\n")
+            for l in range(learners_cnt):
+                for t in classes:
+                    fout.write(f"\n### Dependence {t} (Fold #{l+1})\n")
+                    f_path = f"learner_{l+1}_shap_dependence_class_{t}.png"
+                    fout.write(f"![SHAP Dependence from fold {l+1}]({f_path})")
+
+            # SHAP Decisions
+            dec_plots = [
+                f
+                for f in os.listdir(model_path)
+                if "_sample_" in f and "decisions.png" in f
+            ]
+            if not len(dec_plots):
+                return
+
+            fout.write("\n\n## SHAP Decision plots\n")
+            for decision_type in ["worst", "best"]:
+                for sample in [0, 1, 2, 3]:
+                    for l in range(learners_cnt):
+                        fout.write(
+                            f"\n### {decision_type.capitalize()} decisions for selected sample #{sample+1} (Fold #{l+1})\n"
+                        )
+                        f_path = (
+                            f"learner_{l+1}_sample_{sample}_{decision_type}_decisions.png"
+                        )
+                        fout.write(
+                            f"![SHAP {decision_type} decisions from fold {l+1}]({f_path})"
+                        )
+        except Exception as e:
+            logger.info(
+                f"Exception while saving SHAP explanations. {str(e)}\nContinuing ..."
+            )
\ No newline at end of file
